.. _File Importers:

**************
File Importers
**************

.. toctree::
   :maxdepth: 2

File Importers import raw, unprocessed data into Steamship.

-  A File Importer’s input is a URL or raw bytes.
-  A File Importer's output is raw bytes plus a MIME type.

You can use File Importers when developing Steamship packages, in your own Python app code, or as one-off functions that
import data in the cloud.

.. include:: ./using.rst
.. include:: ./developing.rst
